@@ -1,4 +1,4 @@
-/*      $Id: display.h 27434 2008-08-09 15:43:06Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
         MA 02110-1301, USA.
 
 
-        xfwm4    - (c) 2002-2008 Olivier Fourdan
+        xfwm4    - (c) 2002-2009 Olivier Fourdan
 
  */
 
@@ -63,7 +63,7 @@
 
 #include <gtk/gtk.h>
 #include <glib.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "event_filter.h"
 
@@ -184,6 +184,7 @@ enum
     NET_DESKTOP_NAMES,
     NET_DESKTOP_VIEWPORT,
     NET_FRAME_EXTENTS,
+    NET_MOVERESIZE_WINDOW,
     NET_NUMBER_OF_DESKTOPS,
     NET_REQUEST_FRAME_EXTENTS,
     NET_SHOWING_DESKTOP,
@@ -206,11 +207,14 @@ enum
     NET_WM_ALLOWED_ACTIONS,
     NET_WM_CONTEXT_HELP,
     NET_WM_DESKTOP,
+    NET_WM_FULLSCREEN_MONITORS,
     NET_WM_ICON,
     NET_WM_ICON_GEOMETRY,
     NET_WM_ICON_NAME,
     NET_WM_MOVERESIZE,
     NET_WM_NAME,
+    NET_WM_PID,
+    NET_WM_PING,
     NET_WM_WINDOW_OPACITY,
     NET_WM_WINDOW_OPACITY_LOCKED,
     NET_WM_STATE,
@@ -286,7 +290,7 @@ struct _DisplayInfo
     GdkDisplay *gdisplay;
     Display *dpy;
 
-    SessionClient *session;
+    XfceSMClient *session;
     gboolean quit;
     gboolean reload;
 
@@ -313,8 +317,8 @@ struct _DisplayInfo
     gint nb_screens;
     gchar* hostname;
 
-    Time current_time;
-    Time last_user_time;
+    guint32 current_time;
+    guint32 last_user_time;
 
     gboolean enable_compositor;
 #ifdef HAVE_RENDER
@@ -392,16 +396,16 @@ Client                  *myDisplayGetClientFromXSyncAlarm       (DisplayInfo *,
                                                                  XSyncAlarm);
 #endif /* HAVE_XSYNC */
 ScreenInfo              *myDisplayGetDefaultScreen              (DisplayInfo *);
-Time                     myDisplayUpdateCurrentTime             (DisplayInfo *,
+guint32                  myDisplayUpdateCurrentTime             (DisplayInfo *,
                                                                  XEvent *);
-Time                     myDisplayGetCurrentTime                (DisplayInfo *);
-Time                     myDisplayGetTime                       (DisplayInfo *,
-                                                                 Time);
-Time                     myDisplayGetLastUserTime               (DisplayInfo *);
+guint32                  myDisplayGetCurrentTime                (DisplayInfo *);
+guint32                  myDisplayGetTime                       (DisplayInfo *,
+                                                                 guint32);
+guint32                  myDisplayGetLastUserTime               (DisplayInfo *);
 void                     myDisplaySetLastUserTime               (DisplayInfo *,
-                                                                 Time);
+                                                                 guint32);
 void                     myDisplayUpdateLastUserTime            (DisplayInfo *,
-                                                                 Time);
+                                                                 guint32);
 gboolean                 myDisplayTestXrender                   (DisplayInfo *,
                                                                  gdouble);
 
