@@ -1,4 +1,4 @@
-/*      $Id: hints.h 28365 2008-10-22 20:10:00Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
         oroborus - (c) 2001 Ken Lynch
         Metacity - (c) 2001 Havoc Pennington
-        xfwm4    - (c) 2002-2008 Olivier Fourdan
+        xfwm4    - (c) 2002-2009 Olivier Fourdan
 
  */
 
@@ -205,6 +205,12 @@ void                     setNetFrameExtents                     (DisplayInfo *,
                                                                  int,
                                                                  int,
                                                                  int);
+void                     setNetFullscreenMonitors               (DisplayInfo *,
+                                                                 Window,
+                                                                 gint,
+                                                                 gint,
+                                                                 gint,
+                                                                 gint);
 void                     initNetDesktopInfo                     (DisplayInfo *,
                                                                  Window,
                                                                  int,
@@ -225,12 +231,12 @@ gboolean                 getUTF8String                          (DisplayInfo *,
                                                                  Window,
                                                                  int,
                                                                  gchar **,
-                                                                 int *);
+                                                                 guint *);
 gboolean                 getUTF8StringList                      (DisplayInfo *,
                                                                  Window,
                                                                  int,
                                                                  gchar ***,
-                                                                 int *);
+                                                                 guint *);
 gboolean                 getWindowProp                          (DisplayInfo *,
                                                                  Window,
                                                                  int,
@@ -243,8 +249,8 @@ gboolean                 getWindowRole                          (DisplayInfo *,
                                                                  gchar **);
 Window                   getClientLeader                        (DisplayInfo *,
                                                                  Window);
-gboolean                 getNetWMUserTime                       (DisplayInfo *, 
-                                                                 Window, 
+gboolean                 getNetWMUserTime                       (DisplayInfo *,
+                                                                 Window,
                                                                  guint32 *);
 Window                   getNetWMUserTimeWindow                 (DisplayInfo *,
                                                                  Window);
