@@ -1,4 +1,4 @@
-/*      $Id: startup_notification.c 26999 2008-05-31 14:35:42Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 
         Metacity - (c) 2003 Havoc Pennington
-        xfwm4    - (c) 2002-2008 Olivier Fourdan
+        xfwm4    - (c) 2002-2009 Olivier Fourdan
 
  */
 
@@ -43,6 +43,7 @@
 #include "display.h"
 #include "screen.h"
 #include "client.h"
+#include "startup_notification.h"
 
 #define STARTUP_TIMEOUT (30 /* seconds */ * 1000)
 
@@ -58,13 +59,13 @@ CollectTimedOutData;
 static gboolean sn_startup_sequence_timeout (void *data);
 
 static void
-sn_error_trap_push (SnDisplay * sn_display, Display * dpy)
+sn_error_trap_push (SnDisplay * d, Display * dpy)
 {
     gdk_error_trap_push ();
 }
 
 static void
-sn_error_trap_pop (SnDisplay * sn_display, Display * dpy)
+sn_error_trap_pop (SnDisplay * d, Display * dpy)
 {
     gdk_error_trap_pop ();
 }
@@ -282,15 +283,15 @@ sn_client_startup_properties (Client * c)
     if (sequence != NULL)
     {
         int workspace;
-        Time timestamp;
+        guint32 timestamp;
 
         /* Set initial time */
         timestamp = sn_startup_sequence_get_timestamp (sequence);
         TRACE ("Given startup time: %u", (unsigned int) timestamp);
-        if ((c->user_time == (Time) 0) || TIMESTAMP_IS_BEFORE(c->user_time, timestamp))
+        if ((c->user_time == (guint32) 0) || TIMESTAMP_IS_BEFORE(c->user_time, timestamp))
         {
             c->user_time = timestamp;
-            if (c->user_time != (Time) 0)
+            if (c->user_time != (guint32) 0)
             {
                 myDisplayUpdateLastUserTime (screen_info->display_info, c->user_time);
             }
